Git integration for detecting changed files
Structs
- Changed
File - A changed file in git
- Commit
Entry - Commit metadata for log views
- Commit
Stats - Summary stats for a commit
Enums
- File
Status - Status of a file in git
- GitError
Functions
- get_
changes_ between - Get changes between two commits or refs
- get_
changes_ between_ index - Get changes between a commit and the staged index (commit vs index)
- get_
current_ branch - Get the current git branch name
- get_
file_ at_ commit - Get the content of a file at a specific commit
- get_
head_ content - Get the HEAD content of a file
- get_
recent_ commits - Get recent commits with short stats
- get_
repo_ root - Get the root of the git repository
- get_
staged_ changes - Get list of staged changed files (index vs HEAD)
- get_
staged_ content - Get the staged content of a file
- get_
uncommitted_ changes - Get list of uncommitted changed files (staged and unstaged)
- is_
git_ repo - Check if a directory is a git repository